==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/authorization/entity/MapPermissionTicketEntityFields.java <==
package org.keycloak.models.map.authorization.entity;
public enum MapPermissionTicketEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getId();
        }
    },
    CREATED_TIMESTAMP {
        public static final String FIELD_NAME = "CreatedTimestamp";
        public static final String FIELD_NAME_DASHED = "created-timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (Long) e.getCreatedTimestamp();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setCreatedTimestamp((Long) value);
        }
    },
    GRANTED_TIMESTAMP {
        public static final String FIELD_NAME = "GrantedTimestamp";
        public static final String FIELD_NAME_DASHED = "granted-timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setGrantedTimestamp((Long) value);
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (Long) e.getGrantedTimestamp();
        }
    },
    OWNER {
        public static final String FIELD_NAME = "Owner";
        public static final String FIELD_NAME_DASHED = "owner";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setOwner((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getOwner();
        }
    },
    POLICY_ID {
        public static final String FIELD_NAME = "PolicyId";
        public static final String FIELD_NAME_DASHED = "policy-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setPolicyId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getPolicyId();
        }
    },
    REQUESTER {
        public static final String FIELD_NAME = "Requester";
        public static final String FIELD_NAME_DASHED = "requester";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getRequester();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setRequester((String) value);
        }
    },
    RESOURCE_ID {
        public static final String FIELD_NAME = "ResourceId";
        public static final String FIELD_NAME_DASHED = "resource-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getResourceId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setResourceId((String) value);
        }
    },
    RESOURCE_SERVER_ID {
        public static final String FIELD_NAME = "ResourceServerId";
        public static final String FIELD_NAME_DASHED = "resource-server-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setResourceServerId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getResourceServerId();
        }
    },
    SCOPE_ID {
        public static final String FIELD_NAME = "ScopeId";
        public static final String FIELD_NAME_DASHED = "scope-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getScopeId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setScopeId((String) value);
        }
    },
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authorization/entity/MapPermissionTicketEntityFields.java <==
package org.keycloak.models.map.authorization.entity;
public enum MapPermissionTicketEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setId((String) value);
        }
    },
    CREATED_TIMESTAMP {
        public static final String FIELD_NAME = "CreatedTimestamp";
        public static final String FIELD_NAME_DASHED = "created-timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setCreatedTimestamp((Long) value);
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (Long) e.getCreatedTimestamp();
        }
    },
    GRANTED_TIMESTAMP {
        public static final String FIELD_NAME = "GrantedTimestamp";
        public static final String FIELD_NAME_DASHED = "granted-timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (Long) e.getGrantedTimestamp();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setGrantedTimestamp((Long) value);
        }
    },
    OWNER {
        public static final String FIELD_NAME = "Owner";
        public static final String FIELD_NAME_DASHED = "owner";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setOwner((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getOwner();
        }
    },
    POLICY_ID {
        public static final String FIELD_NAME = "PolicyId";
        public static final String FIELD_NAME_DASHED = "policy-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setPolicyId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getPolicyId();
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setRealmId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getRealmId();
        }
    },
    REQUESTER {
        public static final String FIELD_NAME = "Requester";
        public static final String FIELD_NAME_DASHED = "requester";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getRequester();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setRequester((String) value);
        }
    },
    RESOURCE_ID {
        public static final String FIELD_NAME = "ResourceId";
        public static final String FIELD_NAME_DASHED = "resource-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getResourceId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setResourceId((String) value);
        }
    },
    RESOURCE_SERVER_ID {
        public static final String FIELD_NAME = "ResourceServerId";
        public static final String FIELD_NAME_DASHED = "resource-server-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getResourceServerId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setResourceServerId((String) value);
        }
    },
    SCOPE_ID {
        public static final String FIELD_NAME = "ScopeId";
        public static final String FIELD_NAME_DASHED = "scope-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e) {
            return (String) e.getScopeId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPermissionTicketEntity e, T value) {
            e.setScopeId((String) value);
        }
    },
}
